@@ -62,6 +62,11 @@ def columns(low_coverage_threshold: int = 5) -> List[Tuple[str, str]]:
             f'Number of reference sequence positions with fewer than {low_coverage_threshold} reads'
             f' spanning those positions.'
         ),
+        (
+            'ref_seq_length',
+            'Reference Sequence Length',
+            'Reference sequence length'
+        ),
         (
             'zero_coverage_coords',
             '0X Coverage Regions',
@@ -110,7 +115,7 @@ def create_qc_stats_dataframe(sample_depth_info: Dict[str, mosdepth.MosdepthDept
             comments += [f'Genome coverage below {quality_reqs.min_genome_coverage:.0%}']
         qc_comments.append('; '.join(comments))
     df_stats['qc_comment'] = qc_comments
-    df_stats.loc[mask_pass_breadth, 'qc_comment'] = ''
+    df_stats.loc[qc_pass_mask, 'qc_comment'] = ''
     df_stats.sort_values('sample', inplace=True)
 
     present_cols = set(df_stats.columns)
